@@ -170,7 +170,7 @@ class OMFITcoils(SortedDict, OMFITascii):
                     f, ax = pyplot.subplots(subplot_kw={'projection': projection})
             else:
                 # OMFIT (or the gcf needed to check OMFIT) made a empty figure for us
-                ax = f.add_subplot(111, projection=projection)
+                ax = f.add_subplot(111, projection=projection)  # OKadd
                 try:
                     ax.set_aspect('equal')
                 except NotImplementedError:
@@ -417,7 +417,7 @@ class OMFITfocuscoils(SortedDict, OMFITascii):
                     f, ax = pyplot.subplots(subplot_kw={'projection': '3d'})
             else:
                 # OMFIT (or the gcf needed to check OMFIT) made a empty figure for us
-                ax = f.add_subplot(111, projection='3d')
+                ax = pyplot.subplot(111, projection='3d')
                 try:
                     ax.set_aspect('equal')
                 except NotImplementedError:
