@@ -991,7 +991,7 @@ class OMFITmhdin(OMFITnamelist):
 
         return self
 
-    def to_omas(self, ods=None, update=['oh', 'pf_active', 'flux_loop', 'b_field_pol_probe', 'vessel']):
+    def to_omas(self, ods=None, update=['pf_active', 'flux_loop', 'b_field_pol_probe', 'vessel']):
         """
         Transfers data in EFIT mhdin.dat format to ODS
 
@@ -1015,31 +1015,6 @@ class OMFITmhdin(OMFITnamelist):
         if ods is None:
             ods = ODS()
 
-        # oh
-        if 'oh' in update and 'RE' in self['IN3']:
-            r = self['IN3']['RE']
-            z = self['IN3']['ZE']
-            width = self['IN3']['WE']
-            height = self['IN3']['HE']
-            turns = self['IN3']['ECTURN']
-            elements_id = (self['IN3']['ECID'] - 1).astype(int)
-            rect_code = geo_type_lookup('rectangle', 'pf_active', ods.imas_version, reverse=True)
-            with omas_environment(ods, dynamic_path_creation='dynamic_array_structures'):
-                for i in range(len(r)):
-                    c = elements_id[i]
-                    e = sum(elements_id[:i] == elements_id[i])
-                    ods['pf_active.coil'][c]['name'] = f'OH{c}'
-                    ods['pf_active.coil'][c]['identifier'] = f'OH{c}'
-                    ods['pf_active.coil'][c]['element'][e]['name'] = f'OH{c}_{e}'
-                    ods['pf_active.coil'][c]['element'][e]['identifier'] = f'OH{c}_{e}'
-                    ods['pf_active.coil'][c]['element'][e]['turns_with_sign'] = turns[i]
-                    rect = ods['pf_active.coil'][c]['element'][e]['geometry.rectangle']
-                    rect['r'] = r[i]
-                    rect['z'] = z[i]
-                    rect['width'] = width[i]
-                    rect['height'] = height[i]
-                    ods['pf_active.coil'][c]['element'][e]['geometry.geometry_type'] = rect_code
-
         # pf_active
         if 'pf_active' in update and 'RF' in self['IN3']:
             r = self['IN3']['RF']
@@ -1050,18 +1025,22 @@ class OMFITmhdin(OMFITnamelist):
             angle2 = self['IN3']['AF2']
 
             turns = self['IN3']['FCTURN']
+            if 'TURNFC' in self['IN3']:
+                turnfc = self['IN3']['TURNFC']
+            else:
+                turnfc = np.ones(int(max(self['IN3']['FCID'])))
             elements_id = (self['IN3']['FCID'] - 1).astype(int)
             rect_code = geo_type_lookup('rectangle', 'pf_active', ods.imas_version, reverse=True)
             outline_code = geo_type_lookup('outline', 'pf_active', ods.imas_version, reverse=True)
-            offset = len(ods['pf_active.coil'])
+
             for i in range(len(r)):
-                c = elements_id[i] + offset
+                c = elements_id[i]
                 e = sum(elements_id[:i] == elements_id[i])
                 ods['pf_active.coil'][c]['name'] = f'PF{c}'
                 ods['pf_active.coil'][c]['identifier'] = f'PF{c}'
                 ods['pf_active.coil'][c]['element'][e]['name'] = f'PF{c}_{e}'
                 ods['pf_active.coil'][c]['element'][e]['identifier'] = f'PF{c}_{e}'
-                ods['pf_active.coil'][c]['element'][e]['turns_with_sign'] = turns[i]
+                ods['pf_active.coil'][c]['element'][e]['turns_with_sign'] = turns[i] * turnfc[e]
                 if angle1[i] == 0 and angle2[i] == 0:
                     rect = ods['pf_active.coil'][c]['element'][e]['geometry.rectangle']
                     rect['r'] = r[i]
@@ -1075,6 +1054,31 @@ class OMFITmhdin(OMFITnamelist):
 
                     ods['pf_active.coil'][c]['element'][e]['geometry.geometry_type'] = outline_code
 
+        if 'pf_active' in update and 'RE' in self['IN3']:
+            r = self['IN3']['RE']
+            z = self['IN3']['ZE']
+            width = self['IN3']['WE']
+            height = self['IN3']['HE']
+            turns = self['IN3']['ECTURN']
+            elements_id = (self['IN3']['ECID'] - 1).astype(int)
+            rect_code = geo_type_lookup('rectangle', 'pf_active', ods.imas_version, reverse=True)
+            offset = len(ods['pf_active.coil'])
+            with omas_environment(ods, dynamic_path_creation='dynamic_array_structures'):
+                for i in range(len(r)):
+                    c = elements_id[i] + offset
+                    e = sum(elements_id[:i] == elements_id[i])
+                    ods['pf_active.coil'][c]['name'] = f'OH{c}'
+                    ods['pf_active.coil'][c]['identifier'] = f'OH{c}'
+                    ods['pf_active.coil'][c]['element'][e]['name'] = f'OH{c}_{e}'
+                    ods['pf_active.coil'][c]['element'][e]['identifier'] = f'OH{c}_{e}'
+                    ods['pf_active.coil'][c]['element'][e]['turns_with_sign'] = turns[i]
+                    rect = ods['pf_active.coil'][c]['element'][e]['geometry.rectangle']
+                    rect['r'] = r[i]
+                    rect['z'] = z[i]
+                    rect['width'] = width[i]
+                    rect['height'] = height[i]
+                    ods['pf_active.coil'][c]['element'][e]['geometry.geometry_type'] = rect_code
+
         # flux_loop
         if ('magnetics' in update or 'flux_loop' in update) and 'RSI' in self['IN3']:
             R_flux_loop = np.atleast_1d(self['IN3']['RSI'])
