@@ -169,17 +169,23 @@ def runFunctionWithTimeout(func, *args, **kwargs):
 
 
 # raise error of the tree cannot be opened in 5 seconds
-def safeOpenTree(conn, tree, shot):
+def safeOpenTree(conn, tree, shot, server=None):
     if conn is None:
-        raise OMFITexception('MDS+ connection was unsuccesful')
+        printw('MDS+ connection was unsuccesful, trying to reconnect')
+        conn = safeMDSConnect(server)
 
     finished, _ = runFunctionWithTimeout(conn.openTree, tree, shot)
     if not finished:
-        raise OMFITexception('Opening of MDS+ tree was unsuccesful')
+        printw('Opening of MDS+ tree took more than 10s. It is probably caused by a dead MDS+ connection, trying to open a new connection')
+        conn = safeMDSConnect(server)
+        safeOpenTree(conn, tree, shot)
 
 
 # raise error of the tree cannot be connected in 5 seconds
 def safeMDSConnect(server):
+    if server is None:  # prevents infinite recursion if safeOpenTree calls safeOpenTree again and connection fails
+        raise OMFITexception('MDS+ connection was unsuccesful')
+
     finished, conn = runFunctionWithTimeout(MDSplus.Connection, server)
 
     if not finished or conn is None:
@@ -647,10 +653,11 @@ class OMFITmdsConnectionBaseClass(SortedDict):
                             )
 
                         elif treename is not None:
-                            # Open new tree only if it not already opened
-                            if self.last_open_tree.get(mds_connection_cache_ID, '') != (treename, int(shot)):
-                                safeOpenTree(self[mds_connection_cache_ID], treename, int(shot))
-                                self.last_open_tree[mds_connection_cache_ID] = treename, int(shot)
+                            # Open new tree only if it not already opened, or it it was opened more than 60s before (because of timeout)
+                            opentree, openshot, opentime = self.last_open_tree.get(mds_connection_cache_ID, ['', 0, 0])
+                            if opentree != treename or int(shot) != openshot or opentime < time.time() - 60:
+                                safeOpenTree(self[mds_connection_cache_ID], treename, int(shot), server)
+                                self.last_open_tree[mds_connection_cache_ID] = treename, int(shot), time.time()
 
                             try:
                                 queryResult = mdsplus_data(self[mds_connection_cache_ID].get(pre + signal + post, timeout=timeout))
