@@ -1424,70 +1424,3 @@ class OMFITd3dcompfile(SortedDict, OMFITascii):
                     self[compshot][compsig][sig] = comp
 
         return self
-
-
-class OMFITd3dfitweight(SortedDict, OMFITascii):
-    """
-    OMFIT class to read DIII-D fitweight file
-    """
-
-    def __init__(self, filename, use_leading_comma=None, **kw):
-        r"""
-        OMFIT class to parse DIII-D device files
-
-        :param filename: filename
-
-        :param \**kw: arguments passed to __init__ of OMFITascii
-        """
-        OMFITascii.__init__(self, filename, **kw)
-        SortedDict.__init__(self)
-        self.dynaLoad = True
-
-    @dynaLoad
-    def load(self):
-        self.clear()
-
-        magpri67 = 29
-        magpri322 = 31
-        magprirdp = 8
-        magudom = 5
-        maglds = 3
-        nsilds = 3
-        nsilol = 41
-
-        with open(self.filename, 'r') as f:
-            data = f.read()
-
-        data = data.strip().split()
-
-        for i in data:
-            ifloat = float(i)
-            if ifloat > 100:
-                ishot = ifloat
-                self[ifloat] = []
-            else:
-                self[ishot].append(ifloat)
-
-        for irshot in self:
-            if irshot < 124985:
-                mloop = nsilol
-            else:
-                mloop = nsilol + nsilds
-
-            if irshot < 59350:
-                mprobe = magpri67
-            elif irshot < 91000:
-                mprobe = magpri67 + magpri322
-            elif irshot < 100771:
-                mprobe = magpri67 + magpri322 + magprirdp
-            elif irshot < 124985:
-                mprobe = magpri67 + magpri322 + magprirdp + magudom
-            else:
-                mprobe = magpri67 + magpri322 + magprirdp + magudom + maglds
-            fwtmp2 = self[irshot][mloop : mloop + mprobe]
-            fwtsi = self[irshot][0:mloop]
-            self[irshot] = {}
-            self[irshot]['fwtmp2'] = fwtmp2
-            self[irshot]['fwtsi'] = fwtsi
-
-        return self
