@@ -295,8 +295,7 @@ class OMFITtranspData(SortedDict):
             if fig.axes:
                 axes = fig.axes[0]
             else:
-                pyplot.figure(num=fig.number)
-                axes = pyplot.subplot(111)
+                axes = fig.add_subplot(111)
         else:
             fig = pyplot.gcf()
             axes = pyplot.gca()
